@@ -1,5 +1,5 @@
 """
-SQLObject 0.9.2
+SQLObject 0.9.4
 ---------------
 
 :author: Ian Bicking <ianb@colorstudy.com>
@@ -1228,8 +1228,14 @@ class SQLObject(object):
 
                 # If we don't get it, it's an error:
                 # If we specified an SQL DEFAULT, then we should use that
-                if default is NoDefault and column.defaultSQL is not None:
-                    raise TypeError, "%s() did not get expected keyword argument %s" % (self.__class__.__name__, column.name)
+                if default is NoDefault:
+                    if column.defaultSQL is None:
+                        raise TypeError, "%s() did not get expected keyword argument '%s'" % (self.__class__.__name__, column.name)
+                    else:
+                        # There is defaultSQL for the column - do not put
+                        # the column to kw so that the backend creates the value
+                        continue
+
                 # Otherwise we put it in as though they did pass
                 # that keyword:
 
@@ -1410,9 +1416,6 @@ class SQLObject(object):
     def createJoinTables(cls, ifNotExists=False, connection=None):
         conn = connection or cls._connection
         for join in cls._getJoinsToCreate():
-            if not getattr(join, 'createRelatedTable', True):
-                # This join has requested not to be created
-                continue
             if (ifNotExists and
                 conn.tableExists(join.intermediateTable)):
                 continue
@@ -1423,9 +1426,6 @@ class SQLObject(object):
         conn = connection or cls._connection
         sql = []
         for join in cls._getJoinsToCreate():
-            if not getattr(join, 'createRelatedTable', True):
-                # This join has requested not to be created
-                continue
             sql.append(conn._SO_createJoinTableSQL(join))
         return ';\n'.join(sql)
     createJoinTablesSQL = classmethod(createJoinTablesSQL)
@@ -1453,7 +1453,7 @@ class SQLObject(object):
         for join in cls.sqlmeta.joins:
             if not join:
                 continue
-            if not join.hasIntermediateTable():
+            if not join.hasIntermediateTable() or not getattr(join, 'createRelatedTable', True):
                 continue
             if join.soClass.__name__ > join.otherClass.__name__:
                 continue
@@ -1466,7 +1466,7 @@ class SQLObject(object):
         for join in cls.sqlmeta.joins:
             if not join:
                 continue
-            if not join.hasIntermediateTable():
+            if not join.hasIntermediateTable() or not getattr(join, 'createRelatedTable', True):
                 continue
             if join.soClass.__name__ > join.otherClass.__name__:
                 continue
