@@ -25,3 +25,12 @@ def test_2perform_join():
     alias = Alias(JoinAlias)
     select = JoinAlias.select(JoinAlias.q.parent == alias.q.name)
     assert select.count() == 2
+
+def test_3joins():
+    setupClass(JoinAlias)
+    alias = Alias(JoinAlias)
+    select = JoinAlias.select((JoinAlias.q.name == 'a') & (alias.q.name == 'b'),
+        join=LEFTJOINOn(None, alias, alias.q.name == 'c')
+    )
+    assert str(select) == \
+        "SELECT join_alias.id, join_alias.name, join_alias.parent FROM join_alias LEFT JOIN join_alias  join_alias_alias3 ON ((join_alias_alias3.name) = ('c')) WHERE (((join_alias.name) = ('a')) AND ((join_alias_alias3.name) = ('b')))"
